# Mixture Experimentalist

The Mixture Experimentalist identifies novel experimental conditions under which a hybrid of different experimental sampling strategies is used. 
This mixture can include any custom strategies such as falsification, novelty, crucial experimentation, uncertainty, elimination, aesthetic preferences, and arbitrary preferred/dispreferred regions of the space. The selection of conditions is based on a weighted sum of the scores obtained from these strategies.
 



